@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmain.php 4985 2013-08-10 12:43:01Z gruberroland $
+$Id: confmain.php 5366 2014-05-25 14:37:05Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2012  Roland Gruber
+  Copyright (C) 2003 - 2014  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -161,7 +161,7 @@ foreach ($jsFiles as $jsEntry) {
 		<table border=0 width="100%" class="lamHeader ui-corner-all">
 			<tr>
 				<td align="left" height="30">
-					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
+					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">LDAP Account Manager</a>
 				</td>
 				<td align="right">
 					<?php echo _('Server profile') . ': ' . $conf->getName(); ?>
@@ -253,6 +253,7 @@ $searchLimitOptions = array(
 $limitSelect = new htmlTableExtendedSelect('searchLimit', $searchLimitOptions, array($conf->get_searchLimit()), _("LDAP search limit"), '222');
 $limitSelect->setHasDescriptiveElements(true);
 $serverSettingsContent->addElement($limitSelect, true);
+
 // access level is only visible in Pro version
 if (isLAMProVersion()) {
 	$accessOptions = array(
@@ -265,6 +266,17 @@ if (isLAMProVersion()) {
 	$serverSettingsContent->addElement($accessSelect, true);
 }
 
+// advanced options
+$advancedOptionsContent = new htmlTable();
+// referrals
+$followReferrals = ($conf->getFollowReferrals() === 'true');
+$advancedOptionsContent->addElement(new htmlTableExtendedInputCheckbox('followReferrals',$followReferrals , _('Follow referrals'), '205'), true);
+
+// build advanced options box
+$advancedOptions = new htmlAccordion('advancedOptions_server', array(_('Advanced options') => $advancedOptionsContent), false);
+$advancedOptions->colspan = 15;
+$serverSettingsContent->addElement($advancedOptions, true);
+
 $serverSettings = new htmlFieldset($serverSettingsContent, _("Server settings"), '../../graphics/profiles.png');
 $container->addElement($serverSettings, true);
 $container->addElement(new htmlSpacer(null, '10px'), true);
@@ -272,18 +284,17 @@ $container->addElement(new htmlSpacer(null, '10px'), true);
 // language
 $languageSettingsContent = new htmlTable();
 // read available languages
-$languagefile = "../../config/language";
-if(is_file($languagefile)) {
-	$file = fopen($languagefile, "r");
-	while(!feof($file)) {
-		$line = fgets($file, 1024);
-		if($line == "\n" || $line[0] == "#" || $line == "") continue; // ignore comment and empty lines
-		$line = chop($line);
-		$entry = explode(":", $line);
-		$languages[$entry[2]] = $line;
+$possibleLanguages = getLanguages();
+$defaultLanguage = array('en_GB.utf8');
+if(!empty($possibleLanguages)) {
+	foreach ($possibleLanguages as $lang) {
+		$languages[$lang->description] = $lang->code;
+		if (strpos($conf->get_defaultLanguage(), $lang->code) === 0) {
+			$defaultLanguage = array($lang->code);
+			break;
+		}
 	}
-	fclose($file);
-	$languageSelect = new htmlTableExtendedSelect('lang', $languages, array($conf->get_defaultLanguage()), _("Default language"), '209');
+	$languageSelect = new htmlTableExtendedSelect('lang', $languages, $defaultLanguage, _("Default language"), '209');
 	$languageSelect->setHasDescriptiveElements(true);
 	$languageSettingsContent->addElement($languageSelect, true);
 }
@@ -344,6 +355,12 @@ if (isLAMProVersion()) {
 	}
 	$pwdMailContent->addElement(new htmlTableExtendedInputCheckbox('pwdResetMail_isHTML',$pwdMailIsHTML , _('HTML format'), '553'), true);
 	
+	$pwdMailAllowAlternate = true;
+	if ($conf->getLamProMailAllowAlternateAddress() == 'false') {
+		$pwdMailAllowAlternate = false;
+	}
+	$pwdMailContent->addElement(new htmlTableExtendedInputCheckbox('pwdResetMail_allowAlternate',$pwdMailAllowAlternate , _('Allow alternate address'), '555'), true);
+	
 	$pwdMailBody = new htmlTableExtendedInputTextarea('pwdResetMail_body', $conf->getLamProMailText(), 50, 4, _('Text'), '552');
 	$pwdMailContent->addElement($pwdMailBody, true);
 	
@@ -435,6 +452,7 @@ $password1 = new htmlTableExtendedInputField(_("New password"), 'passwd1', null,
 $password1->setIsPassword(true);
 $password2 = new htmlTableExtendedInputField(_("Reenter password"), 'passwd2');
 $password2->setIsPassword(true);
+$password2->setSameValueFieldID('passwd1');
 $securitySettingsContent->addElement($password1, true);
 $securitySettingsContent->addElement($password2, true);
 $securitySettings = new htmlFieldset($securitySettingsContent, _("Security settings"), '../../graphics/security.png');
@@ -486,6 +504,12 @@ function checkInput() {
 	if ((strpos($_POST['serverurl'], 'ldaps://') !== false) && ($_POST['useTLS'] == 'yes')) {
 		$errors[] = array("ERROR", _('You cannot use SSL and TLS encryption at the same time. Please use either "ldaps://" or TLS.'));
 	}
+	if (isset($_POST['followReferrals']) && ($_POST['followReferrals'] == 'on')) {
+		$conf->setFollowReferrals('true');
+	}
+	else {
+		$conf->setFollowReferrals('false');
+	}
 /*	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
 		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
 	}*/
@@ -505,6 +529,12 @@ function checkInput() {
 		else {
 			$conf->setLamProMailIsHTML('false');
 		}
+		if (isset($_POST['pwdResetMail_allowAlternate']) && ($_POST['pwdResetMail_allowAlternate'] == 'on')) {
+			$conf->setLamProMailAllowAlternateAddress('true');
+		}
+		else {
+			$conf->setLamProMailAllowAlternateAddress('false');
+		}
 		$conf->setLamProMailText($_POST['pwdResetMail_body']);
 	}
 	$adminText = $_POST['admins'];
