@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profmanage.php 4715 2013-01-15 18:58:33Z gruberroland $
+$Id: profmanage.php 5366 2014-05-25 14:37:05Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2013  Roland Gruber
+  Copyright (C) 2003 - 2014  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -182,7 +182,7 @@ echo $_SESSION['header'];
 		<table border=0 width="100%" class="lamHeader ui-corner-all">
 			<tr>
 				<td align="left" height="30">
-					<a class="lamHeader" href="http://www.ldap-account-manager.org/" target="new_window">&nbsp;<img src="../../graphics/logo32.png" width=24 height=24 class="align-middle" alt="LDAP Account Manager">&nbsp;&nbsp;LDAP Account Manager</a>
+					<a class="lamLogo" href="http://www.ldap-account-manager.org/" target="new_window">LDAP Account Manager</a>
 				</td>
 				<td align="right" height=20>
 					<a href="conflogin.php"><IMG alt="configuration" src="../../graphics/undo.png">&nbsp;<?php echo _("Back to profile login") ?></a>
@@ -247,6 +247,7 @@ $container->addElement($profileNewPwd1, true);
 $profileNewPwd2 = new htmlTableExtendedInputField(_("Reenter password"), 'addpassword2');
 $profileNewPwd2->setIsPassword(true);
 $profileNewPwd2->setFieldSize(15);
+$profileNewPwd2->setSameValueFieldID('addpassword');
 $container->addElement($profileNewPwd2, true);
 $newProfileButton = new htmlButton('btnAddProfile', _('Add'));
 $newProfileButton->setOnClick("jQuery('#action').val('add');showConfirmationDialog('" . _("Add profile") . "', '" . 
@@ -285,6 +286,7 @@ $container->addElement($profileSetPwd1, true);
 $profileSetPwd2 = new htmlTableExtendedInputField(_("Reenter password"), 'setpassword2');
 $profileSetPwd2->setIsPassword(true);
 $profileSetPwd2->setFieldSize(15);
+$profileSetPwd2->setSameValueFieldID('setpassword');
 $container->addElement($profileSetPwd2, true);
 $setPasswordProfileButton = new htmlButton('btnSetPasswordProfile', _('Set profile password'));
 $setPasswordProfileButton->setOnClick("jQuery('#action').val('setpass');showConfirmationDialog('" . _("Set profile password") . "', '" . 
