@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: massBuildAccounts.php 5121 2013-11-17 10:16:58Z gruberroland $
+$Id: massBuildAccounts.php 5337 2014-04-12 17:51:47Z gruberroland $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2013  Roland Gruber
+  Copyright (C) 2004 - 2014  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -97,7 +97,7 @@ if (isAccountTypeHidden($scope)) {
 	logNewMessage(LOG_ERR, 'User tried to access hidden upload: ' . $scope);
 	die();
 }
-if (!checkIfNewEntriesAreAllowed($scope)) {
+if (!checkIfNewEntriesAreAllowed($scope) || !checkIfWriteAccessIsAllowed($scope)) {
 	logNewMessage(LOG_ERR, 'User tried to access forbidden upload: ' . $scope);
 	die();
 }
@@ -159,7 +159,7 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 	
 	// check if values in unique columns are correct
 	for ($i = 0; $i < sizeof($columns); $i++) {
-		if (isset($columns[$i]['unique']) && ($columns[$i]['unique'] == true)) {
+		if (isset($columns[$i]['unique']) && ($columns[$i]['unique'] == true) && isset($ids[$columns[$i]['name']])) {
 			$colNumber = $ids[$columns[$i]['name']];
 			$values_given = array();
 			for ($r = 0; $r < sizeof($data); $r++) {
